@@ -32,7 +32,7 @@ use NetAddr::IP::Util qw(
 
 use vars qw(@ISA @EXPORT_OK $VERSION $Accept_Binary_IP $Old_nth $AUTOLOAD *Zero);
 
-$VERSION = do { my @r = (q$Revision: 1.48 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r };
+$VERSION = do { my @r = (q$Revision: 1.52 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r };
 
 require Exporter;
 
@@ -48,6 +48,10 @@ $Accept_Binary_IP = 0;
 $Old_nth = 0;
 *Zero = \&Zeros;
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 NetAddr::IP::Lite - Manages IPv4 and IPv6 addresses and subnets
@@ -195,6 +199,7 @@ my $_zero = pack('L4',0,0,0,0);
 my $_ones = ~$_zero;
 my $_v4mask = pack('L4',0xffffffff,0xffffffff,0xffffffff,0);
 my $_v4net = ~ $_v4mask;
+my $_ipv4FFFF = pack('N4',0,0,0xffff,0);
 
 sub Zeros() {
   return $_zero;
@@ -504,6 +509,8 @@ sub _new ($$$) {
 
 =item C<-E<gt>new6([$addr, [ $mask]])>
 
+=item C<-E<gt>new6FFFF([$addr, [ $mask]])>
+
 =item C<-E<gt>new_no([$addr, [ $mask]])>
 
 =item C<-E<gt>new_from_aton($netaddr)>
@@ -514,9 +521,14 @@ sub _new ($$$) {
 
 =item C<-E<gt>new_cis6("$addr $mask)>
 
-The first two methods create a new address with the supplied address in
+The first three methods create a new address with the supplied address in
 C<$addr> and an optional netmask C<$mask>, which can be omitted to get 
-a /32 or /128 netmask for IPv4 / IPv6 addresses respectively.
+a /32 or /128 netmask for IPv4 / IPv6 addresses respectively. 
+
+new6FFFF specifically returns an IPv4 address in IPv6 format according to RFC4291
+
+  new6		     ::xxxx:xxxx
+  new6FFFF	::FFFF:xxxx:xxxx
 
 The third method C<new_no> is exclusively for IPv4 addresses and filters
 improperly formatted
@@ -699,6 +711,12 @@ sub new6($;$$) {
   goto &_xnew;
 }
 
+sub new6FFFF($;$$) {
+  my $ip = _xnew(1,@_);
+  $ip->{addr} |= $_ipv4FFFF;
+  return $ip;
+}
+
 sub new_cis($;$$) {
   my @in = @_;
   if ( $in[1] && $in[1] =~ m!^(.+)\s+(.+)$! ) {
@@ -1571,7 +1589,7 @@ sub import {
 
 =head1 AUTHORS
 
-Luis E. Muoz E<lt>luismunoz@cpan.orgE<gt>,
+Luis E. Muñoz E<lt>luismunoz@cpan.orgE<gt>,
 Michael Robinton E<lt>michael@bizsystems.comE<gt>
 
 =head1 WARRANTY
@@ -1581,8 +1599,8 @@ so by using it you accept any and all the liability.
 
 =head1 COPYRIGHT
 
- This software is (c) Luis E. Muoz, 1999 - 2005
- and (c) Michael Robinton, 2006 - 2012.
+ This software is (c) Luis E. Muñoz, 1999 - 2005
+ and (c) Michael Robinton, 2006 - 2014.
 
 All rights reserved.
 
